Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(651)

Unified Diff: components/security_state/security_state_model.cc

Issue 2344043003: Rename HTTP bad-related flags to be more clear (Closed)
Patch Set: sfijdf Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ssl/ssl_browser_tests.cc ('k') | components/security_state/security_state_model_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/security_state/security_state_model.cc
diff --git a/components/security_state/security_state_model.cc b/components/security_state/security_state_model.cc
index e8dba3c1062248533b2db58122676827f4c07e86..b19c736310f72aad9ca972996c038597df9b9ddb 100644
--- a/components/security_state/security_state_model.cc
+++ b/components/security_state/security_state_model.cc
@@ -23,27 +23,27 @@ namespace {
enum MarkHttpStatus { NEUTRAL, NON_SECURE, HTTP_SHOW_WARNING, LAST_STATUS };
// If |switch_or_field_trial_group| corresponds to a valid
// MarkNonSecureAs group, sets |*level| and |*histogram_status| to the
// appropriate values and returns true. Otherwise, returns false.
bool GetSecurityLevelAndHistogramValueForNonSecureFieldTrial(
std::string switch_or_field_trial_group,
bool displayed_sensitive_input_on_http,
SecurityStateModel::SecurityLevel* level,
MarkHttpStatus* histogram_status) {
- if (switch_or_field_trial_group == switches::kMarkNonSecureAsNeutral) {
+ if (switch_or_field_trial_group == switches::kMarkHttpAsNeutral) {
*level = SecurityStateModel::NONE;
*histogram_status = NEUTRAL;
return true;
}
- if (switch_or_field_trial_group == switches::kMarkNonSecureAsNonSecure) {
+ if (switch_or_field_trial_group == switches::kMarkHttpAsDangerous) {
*level = SecurityStateModel::SECURITY_ERROR;
*histogram_status = NON_SECURE;
return true;
}
if (switch_or_field_trial_group ==
- switches::kMarkNonSecureWithPasswordsOrCcAsNonSecure) {
+ switches::kMarkHttpWithPasswordsOrCcWithChip) {
if (displayed_sensitive_input_on_http) {
*level = SecurityStateModel::HTTP_SHOW_WARNING;
*histogram_status = HTTP_SHOW_WARNING;
@@ -61,7 +61,7 @@ SecurityStateModel::SecurityLevel GetSecurityLevelForNonSecureFieldTrial(
bool displayed_sensitive_input_on_http) {
std::string choice =
base::CommandLine::ForCurrentProcess()->GetSwitchValueASCII(
- switches::kMarkNonSecureAs);
+ switches::kMarkHttpAs);
std::string group = base::FieldTrialList::FindFullName("MarkNonSecureAs");
const char kEnumeration[] = "MarkHttpAs";
« no previous file with comments | « chrome/browser/ssl/ssl_browser_tests.cc ('k') | components/security_state/security_state_model_unittest.cc » ('j') | no next file with comments »
@@ -23,27 +23,27 @@ namespace {
enum MarkHttpStatus { NEUTRAL, NON_SECURE, HTTP_SHOW_WARNING, LAST_STATUS };
// If |switch_or_field_trial_group| corresponds to a valid
-// MarkNonSecureAs group, sets |*level| and |*histogram_status| to the
+// MarkHttpAs group, sets |*level| and |*histogram_status| to the
// appropriate values and returns true. Otherwise, returns false.
bool GetSecurityLevelAndHistogramValueForNonSecureFieldTrial(

Powered by Google App Engine
This is Rietveld 408576698